DIV.form FIELDSET DIV.location INPUT[type="text"] {
	width: 20%;
	margin-right: 20px;
}

DIV.form FIELDSET DIV.location IMG {
	vertical-align: top;
}

DIV.mapviewer INPUT[type="text"] {
	width: auto !important;
}